even_odd_ratio_error_db

Function even_odd_ratio_error_db 

pub fn even_odd_ratio_error_db(
    wdf: &[f64],
    reference: &[f64],
    fundamental_hz: f64,
    sample_rate: f64,
    n_harmonics: usize,
) -> f64
Compute even/odd harmonic ratio error between WDF and reference in dB.

Returns the absolute difference in even_odd_ratio_db between the two signals. Near zero for two signals with the same harmonic character; large when one has asymmetric and the other symmetric distortion.