pub fn quick_validate(
circuit_path: &Path,
golden_path: Option<&Path>,
sample_rate: f64,
) -> Result<ComparisonResult, RunnerError>Expand description
Quick validation of a single circuit with default settings.
pub fn quick_validate(
circuit_path: &Path,
golden_path: Option<&Path>,
sample_rate: f64,
) -> Result<ComparisonResult, RunnerError>Quick validation of a single circuit with default settings.